function x = mutPerm2Opt(x, o, varargin)
%
% MUTPERM2OPT Mutation (perturbation) operator for permutation
% representation. Uses 2-Opt move (changes the order of some subsequence of
% the permutation).
%

% Process options
if ~exist('o','var') | isempty(o), o = struct; end
if iscell(o), o = struct(o{:}); end
if ~isfield(o,'verbose'), o.verbose = 0; end

% Set probability of applying the operator to 0.1, if it is not given as
% argument.
pmut = 0.1;
if ~isempty(varargin),
    pmut = varargin{1};
end

% Print message
if o.verbose, fprintf('2-Opt Mutation: Pmut = %.2f', pmut); end

% Select the permutations in x that should be mutated.
[popsize, dim] = size(x);
imut = find(rand(popsize,1) <= pmut);

% Perform the mutation on selected tours
for i = 1:length(imut),
    x(imut(i),:) = performMutPerm2Opt(x(imut(i),:), varargin{2:end});
    chkPerm(x(i,:),'In after one mutation.');
    if o.verbose, fprintf('.'); end
end

if o.verbose, fprintf('done.\n'); end
chkPerm(x,'In after mutation.');

return;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function x = performMutPerm2Opt(x, varargin)

if length(unique(x)) ~= length(x),
    error('SCP:mutPerm2Opt','Wrong input');
end

n = length(x);
n1 = ceil(n*rand);
n2 = mod(ceil((n-1)*rand) + n1 - 1, n) + 1;

if n1 > n2,
    [n1, n2] = deal(n2, n1);
end

x(n1:n2) = x(n2:-1:n1); 

if length(unique(x)) ~= length(x),
    error('SCP:mutPerm2Opt','Wrong output');
end