% Clear the workspace
clear;

% Call the local search method for the fBinRosenbrock objective function.
% Its initial point is set to a random bit string of length 104 and its
% perturbation operator is set to mutSwitchBit. It can be set also to
% mutSwitch2Bits.
xstart = rand(1,104)>0.5;
[x,fx,hist] = minLocalSearchFirstImproving(...
    @fBinRosenbrock, ...
    xstart, ...
    @mutSwitch2Bit, ...
    {}, ...
    {});

% Plot the history of the optimization
[ax,h1,h2] = plotyy(hist.evals, hist.fmin, hist.evals, hist.nonimpr, @step, @saw);
xlabel('evaluations');
ylabel(ax(1),'loss function');
ylabel(ax(2),'# of nonimproving from last improving');

% Plot the contour plot of the evaluation function and the trajectory of
% the algorithm in the 2D real space.
x = tranBinToRealRosenbrock(hist.x);
xf = -2.048:0.05:2.048;
[xx,yy] = meshgrid(xf,xf);
ff = fRealRosenbrock([xx(:) yy(:)]);
ff = reshape(ff,size(xx));
figure;
contour(xf,xf,ff,32); hold on;
plot(x(:,1), x(:,2), 'bx-');
hold on;

% optimum
plot([1 1], [1 1], 'r.', 'MarkerSize',15);
