% Clear the workspace
clear;

% Call the local search method for the fRealRosenbrock objective function.
% Its initial point is set to a pair of real random numbers in interval
% (-2.048, 2.048). Perturbation operator is set to mutSampleGauss which
% samples a new point from an isotropic Gaussian distribution with standard
% deviation 0.1 (as given in the last argument).
xstart = -2.048 + 4.096*rand(1,2);
[x,fx,hist] = minLocalSearchFirstImproving(...
    @fRealRosenbrock, ...
    xstart, ...
    @mutSampleGauss, ...
    {}, ...
    {1, .1});

% Plot the history of the optimization
[ax,h1,h2] = plotyy(hist.evals, hist.fmin, hist.evals, hist.nonimpr, @steplogy, @saw);
xlabel('evaluations');
ylabel(ax(1),'loss function');
ylabel(ax(2),'# of nonimproving from last improving');

% Plot the contour lines of the evaluation function and the trajectory of
% the algorithm in 2D real space.
x = hist.x;
xf = -2.048:0.05:2.048;
[xx,yy] = meshgrid(xf,xf);
ff = fRealRosenbrock([xx(:) yy(:)]);
ff = reshape(ff,size(xx));
figure;
contour(xf,xf,ff,32); hold on;
plot(x(:,1), x(:,2), 'bx-');
hold on;

% optimum
plot([1 1], [1 1], 'r.', 'MarkerSize',15);
