function xout = tranBinToRealRosenbrock(x)
%
% TRANBINTOREALROSENBROCK Transforms the binary representation on 2D real
% representation for evaluation with the Rosenbrock's function.
%

% Set the size of the real search space
minx = -2.048;
maxx = 2.048;
dx = maxx - minx;

% Determine how many bits are used to encode each of the two coordinates
% (length(x)/2)
n = floor(size(x,2)/2);
% Divide the binary string into two parts - one encoding the first
% coordinate and one encoding the second coordinate
x1 = x(:,1:n);
x2 = x(:,(n+1):2*n);

% Transform both binary numbers into decimals
x1 = bin2dec(char(x1+'0'));
x2 = bin2dec(char(x2+'0'));

% Translate and scale those decimals into our real coordinates
xout(:,1) = minx + x1 * dx / (2^n-1);
xout(:,2) = minx + x2 * dx / (2^n-1);

