function visTSPHist(cities, hist, speed)
%
% VISTSPHIST Visualizes history of the local search method on the TSP
% problem.
%

% Set the default value for the speed of algorithm, if not given in
% arguments
if nargin < 3,
    speed = 1000;
end

% Extract relevant info from the hist structure
iter = hist.evals;
n = length(iter);
x = hist.x;
f = hist.fmin;
paus = hist.nonimpr;

% Create figure and draw the inital tour and the fisrt better tour found
figure; hold on;
hnew = plotTSP(cities, x(2,:), {'ko-', 'LineWidth', 2});
hbsf = plotTSP(cities, x(1,:), {'rx:', 'LineWidth', 2});
% Create legend
legend({'New path','Old path'},'Location','NorthEastOutside');
% Set equal axes
axis equal;

% Step through all the rest of the sequntially improving tours
for i = 2:n,
    % Plot the new TSP
    if i < n,
        plotTSP(cities, x(i+1,:), [], hnew);
    end
    % Plot the old TSP
    plotTSP(cities, x(i,:), [], hbsf);
    % Assign title
    tit = sprintf('Evaluations: %d    Length of BSF tour: %.3f', ...
        iter(i), f(i));
    title(tit);
    % Wait for a moment
    if speed > 0,
        if i < n,
            pause(paus(i+1) / speed);
        end
    else
        pause;
    end
end
